Summary
=======

-  Maps (dictionaries) are associative memory organization structures.

-  Skip lists are linked lists that provide expected :math:`O(\log(n))`
   searches.

-  An octree provides an efficient way to reduce the number of
   colors used to represent an image.

-  Text-based pattern matching is a very common problem in many
   application areas.

-  Simple pattern matching is inefficient.

-  DFA graphs are easy to use but complex to build.

-  KMP graphs are easy to use and easy to build.
